<?php

namespace Litecms\Zingapp\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Database\RequestScope;
use Litecms\Zingapp\Forms\Cuisine as CuisineForm;
use Litecms\Zingapp\Http\Requests\CuisineResourceRequest;
use Litecms\Zingapp\Http\Resources\CuisineResource;
use Litecms\Zingapp\Http\Resources\CuisinesCollection;
use Litecms\Zingapp\Models\Cuisine;
use Litecms\Zingapp\Scopes\CuisineResourceScope;


/**
 * Resource controller class for cuisine.
 */
class CuisineResourceController extends BaseController
{

    /**
     * Initialize cuisine resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = CuisineForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('litecms.zingapp.modules'), 'zingapp', guard_url('zingapp'));
    }

    /**
     * Display a list of cuisine.
     *
     * @return Response
     */
    public function index(CuisineResourceRequest $request)
    {
        $request = $request->all();
        $page = CuisineActions::run('paginate', $request);

        $data = new CuisinesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('zingapp::cuisine.names'))
            ->view('zingapp::cuisine.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display cuisine.
     *
     * @param Request $request
     * @param Model   $cuisine
     *
     * @return Response
     */
    public function show(CuisineResourceRequest $request, Cuisine $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new CuisineResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('zingapp::cuisine.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('zingapp::cuisine.show')
            ->output();
    }

    /**
     * Show the form for creating a new cuisine.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CuisineResourceRequest $request, Cuisine $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new CuisineResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('zingapp::cuisine.name'))
            ->view('zingapp::cuisine.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new cuisine.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CuisineResourceRequest $request, Cuisine $model)
    {
        try {
            $request = $request->all();
            $model = CuisineAction::run('store', $model, $request);
            $data = new CuisineResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('zingapp::cuisine.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('zingapp/cuisine/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/zingapp/cuisine'))
                ->redirect();
        }

    }

    /**
     * Show cuisine for editing.
     *
     * @param Request $request
     * @param Model   $cuisine
     *
     * @return Response
     */
    public function edit(CuisineResourceRequest $request, Cuisine $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new CuisineResource($model);
        // return view('zingapp::cuisine.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('zingapp::cuisine.name'))
            ->view('zingapp::cuisine.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the cuisine.
     *
     * @param Request $request
     * @param Model   $cuisine
     *
     * @return Response
     */
    public function update(CuisineResourceRequest $request, Cuisine $model)
    {
        try {
            $request = $request->all();
            $model = CuisineAction::run('update', $model, $request);
            $data = new CuisineResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('zingapp::cuisine.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('zingapp/cuisine/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('zingapp/cuisine/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the cuisine.
     *
     * @param Model   $cuisine
     *
     * @return Response
     */
    public function destroy(CuisineResourceRequest $request, Cuisine $model)
    {
        try {

            $request = $request->all();
            $data = new CuisineResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('zingapp::cuisine.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('zingapp/cuisine/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('zingapp/cuisine/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
